@@ -1,8 +1,17 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 from __future__ import annotations
 
 from abc import ABC, abstractclassmethod, abstractmethod
 from pathlib import Path
-from typing import Optional, Protocol, Sequence, Tuple, Union
+from typing import Optional, Sequence, Tuple, Union
+
+
+try:
+    from typing import Protocol
+except ImportError:
+    from typing_extensions import Protocol
 
 import acconeer.exptool as et
 
