@@ -1,3 +1,6 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 from __future__ import annotations
 
 from enum import Enum, unique
@@ -45,7 +48,32 @@ class Profile(Enum):
 
 @unique
 class PRF(Enum):
-    """Pulse Repetition Frequency (PRF)"""
+    """Pulse Repetition Frequency (PRF)
+
+    Pulse Repetition Frequency, PRF, is the frequency at which pulses are sent out from the radar
+    system. The measurement time is approximately proportional to the PRF. The higher the PRF, the
+    shorter the measurement time.
+
+    This parameter sets the Maximum Measurable Distance, MMD, that can be achieved. MMD is the
+    maximum value for the end point, i.e., the start point + (number of points * step length). For
+    example, an MMD of 7.0 m means that the range cannot be set further out than 7.0 m.
+
+    It also sets the Maximum Unambiguous Range, MUR, that can be achieved. MUR is the maximum
+    distance at which an object can be located to guarantee that its reflection corresponds to the
+    most recent transmitted pulse. Objects farther away than the MUR may fold into the measured
+    range. For example, with a MUR of 11.5 m, an object at 13.5 m could become visible at 2 m.
+
+    ================= ======== ====== ======
+    PRF Setting            PRF    MMD    MUR
+    ================= ======== ====== ======
+    PRF_19_5_MHZ [*]_ 19.5 MHz  3.1 m  7.7 m
+    PRF_13_0_MHZ      13.0 MHz  7.0 m 11.5 m
+    PRF_8_7_MHZ        8.7 MHz 12.7 m 17.3 m
+    PRF_6_5_MHZ        6.5 MHz 18.5 m 23.1 m
+    ================= ======== ====== ======
+
+    .. [*] 19.5MHz is only available for profile 1 and 2.
+    """
 
     PRF_19_5_MHz = 19500000
     PRF_13_0_MHz = 13000000
@@ -65,11 +93,11 @@ class PRF(Enum):
 class IdleState(Enum):
     """Idle state
 
-    Idle state ``DEEP_SLEEP`` is the deepest state where as much of the
-    sensor hardware as possible is shut down and idle state ``READY`` is
+    Idle state :attr:`DEEP_SLEEP` is the deepest state where as much of the
+    sensor hardware as possible is shut down and idle state :attr:`READY` is
     the lightest state where most of the sensor hardware is kept on.
 
-    ``DEEP_SLEEP`` is the slowest to transition from while ``READY`` is
+    :attr:`DEEP_SLEEP` is the slowest to transition from while :attr:`READY` is
     the fastest.
     """
 
