@@ -3,16 +3,15 @@
 
 from __future__ import annotations
 
-import abc
 import logging
 import queue
 import shutil
 import time
 from pathlib import Path
-from typing import Any, Callable, Optional, Tuple, Type
+from typing import Any, Callable, Optional, Tuple
 from uuid import UUID
 
-import attrs
+from typing_extensions import Protocol
 
 from PySide6.QtCore import QDeadlineTimer, QObject, QThread, Signal
 from PySide6.QtWidgets import QApplication, QWidget
@@ -23,7 +22,6 @@ from acconeer.exptool import a121
 from acconeer.exptool.app.new._enums import (
     ConnectionInterface,
     ConnectionState,
-    PluginFamily,
     PluginGeneration,
     PluginState,
 )
@@ -43,6 +41,7 @@ from acconeer.exptool.app.new.backend import (
 from acconeer.exptool.app.new.storage import get_config_dir, remove_temp_dir
 from acconeer.exptool.utils import USBDevice  # type: ignore[import]
 
+from .plugin_protocols import PlotPluginInterface, ViewPluginInterface
 from .port_updater import PortUpdater
 from .rate_calc import RateCalculator
 
@@ -50,53 +49,27 @@ from .rate_calc import RateCalculator
 log = logging.getLogger(__name__)
 
 
-class AppModelAwarePlugin:
-    def __init__(self, app_model: AppModel) -> None:
-        app_model.sig_notify.connect(self.on_app_model_update)
+class PluginSpec(Protocol):
+    """Defines what AppModel needs to know about a plugin.
 
-    def on_app_model_update(self, app_model: AppModel) -> None:
-        pass
+    Implementations are free to add additional fields.
+    """
 
+    key: str
+    generation: PluginGeneration
 
-class PlotPlugin(AppModelAwarePlugin, abc.ABC):
-    def __init__(self, app_model: AppModel, plot_layout: pg.GraphicsLayout) -> None:
-        super().__init__(app_model=app_model)
-        self.plot_layout = plot_layout
+    def create_backend_plugin(
+        self, callback: Callable[[Message], None], key: str
+    ) -> BackendPlugin:
+        ...
 
-        app_model.sig_message_plot_plugin.connect(self.handle_message)
+    def create_view_plugin(self, app_model: AppModel, view_widget: QWidget) -> ViewPluginInterface:
+        ...
 
-    @abc.abstractmethod
-    def handle_message(self, message: GeneralMessage) -> None:
-        pass
-
-    @abc.abstractmethod
-    def draw(self) -> None:
-        pass
-
-
-class ViewPlugin(AppModelAwarePlugin, abc.ABC):
-    def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
-        super().__init__(app_model=app_model)
-        self.app_model = app_model
-        self.view_widget = view_widget
-
-        app_model.sig_message_view_plugin.connect(self.handle_message)
-
-    @abc.abstractmethod
-    def handle_message(self, message: GeneralMessage) -> None:
-        pass
-
-
-@attrs.frozen(kw_only=True)
-class Plugin:
-    generation: PluginGeneration = attrs.field()
-    key: str = attrs.field()
-    title: str = attrs.field()
-    description: Optional[str] = attrs.field(default=None)
-    family: PluginFamily = attrs.field()
-    backend_plugin: Type[BackendPlugin] = attrs.field()
-    plot_plugin: Type[PlotPlugin] = attrs.field()
-    view_plugin: Type[ViewPlugin] = attrs.field()
+    def create_plot_plugin(
+        self, app_model: AppModel, plot_layout: pg.GraphicsLayout
+    ) -> PlotPluginInterface:
+        ...
 
 
 class _BackendListeningThread(QThread):
@@ -135,8 +108,8 @@ class AppModel(QObject):
     sig_status_message = Signal(object)
     sig_update_rate = Signal(float, float)
 
-    plugins: list[Plugin]
-    plugin: Optional[Plugin]
+    plugins: list[PluginSpec]
+    plugin: Optional[PluginSpec]
 
     backend_plugin_state: Any
 
@@ -150,8 +123,9 @@ class AppModel(QObject):
     usb_connection_device: Optional[USBDevice]
     available_usb_devices: list[USBDevice]
     saveable_file: Optional[Path]
+    autoconnect_enabled: bool
 
-    def __init__(self, backend: Backend, plugins: list[Plugin]) -> None:
+    def __init__(self, backend: Backend, plugins: list[PluginSpec]) -> None:
         super().__init__()
         self._backend = backend
         self._listener = _BackendListeningThread(self._backend, self)
@@ -179,6 +153,7 @@ class AppModel(QObject):
         self.available_tagged_ports = []
         self.available_usb_devices = []
         self.saveable_file = None
+        self.autoconnect_enabled = False
 
         self.rate_calc = RateCalculator()
 
@@ -392,7 +367,7 @@ class AppModel(QObject):
                 self.send_status_message(f"Recognized USB device: {self.usb_connection_device}")
                 connect = True
 
-        if connect:
+        if connect and self.autoconnect_enabled:
             self._autoconnect()
 
         self.broadcast()
@@ -516,34 +491,46 @@ class AppModel(QObject):
         self.plugin_state = state
         self.broadcast()
 
-    def load_plugin(self, plugin: Optional[Plugin]) -> None:
+    def set_autoconnect_enabled(self, autoconnect_enabled: bool) -> None:
+        self.autoconnect_enabled = autoconnect_enabled
+        self.broadcast()
+
+    def _unload_current_plugin(self) -> None:
+        log.debug("AppModel is unloading its current plugin")
+        self.sig_load_plugin.emit(None)
+        self._update_saveable_file(None)
+        self.backend_plugin_state = None
+        if self.plugin is not None:
+            self.plugin_state = PluginState.UNLOADING
+
+        self.broadcast()
+
+        self._put_backend_task("unload_plugin", {}, on_error=self.emit_error)
+
+    def _load_plugin_cache(self, generation: PluginGeneration, key: str) -> None:
+        config_path = self._get_plugin_config_path(generation, key)
+        try:
+            data = config_path.read_bytes()
+        except Exception:
+            pass
+        else:
+            self.put_backend_plugin_task("deserialize", {"data": data})
+
+    def load_plugin(self, plugin: Optional[PluginSpec]) -> None:
+        log.debug(f"AppModel is loading the plugin {plugin}")
         if plugin == self.plugin:
             return
 
-        self._update_saveable_file(None)
-        self.backend_plugin_state = None
+        self._unload_current_plugin()
 
-        if plugin is None:
-            self._put_backend_task("unload_plugin", {}, on_error=self.emit_error)
-            if self.plugin is not None:
-                self.plugin_state = PluginState.UNLOADING
-        else:
+        if plugin is not None:
             self._put_backend_task(
                 "load_plugin",
-                {"plugin": plugin.backend_plugin, "key": plugin.key},
+                {"plugin": plugin.create_backend_plugin, "key": plugin.key},
                 on_error=self.emit_error,
             )
-
-            config_path = self._get_plugin_config_path(plugin.generation, plugin.key)
-            try:
-                data = config_path.read_bytes()
-            except Exception:
-                pass
-            else:
-                self.put_backend_plugin_task("deserialize", {"data": data})
-
-            if self.plugin is not None:
-                self.plugin_state = PluginState.LOADING
+            self._load_plugin_cache(plugin.generation, plugin.key)
+            self.plugin_state = PluginState.LOADING
 
         self.sig_load_plugin.emit(plugin)
         self.plugin = plugin
@@ -583,7 +570,7 @@ class AppModel(QObject):
         self.plugin_state = PluginState.LOADED_STARTING
         self.broadcast()
 
-    def _find_plugin(self, find_key: Optional[str]) -> Plugin:  # TODO: Also find by generation
+    def _find_plugin(self, find_key: Optional[str]) -> PluginSpec:  # TODO: Also find by generation
         if find_key is None:
             raise Exception
 
